@@ -8,20 +8,20 @@ import org.gcube.portlets.user.td.columnwidget.client.dimension.CodelistSelectio
 import org.gcube.portlets.user.td.columnwidget.client.mapping.ColumnMappingDialog;
 import org.gcube.portlets.user.td.columnwidget.client.mapping.ColumnMappingListProperties;
 import org.gcube.portlets.user.td.columnwidget.client.mapping.ColumnMappingListener;
-import org.gcube.portlets.user.td.columnwidget.client.properties.ColumnDataPropertiesCombo;
-import org.gcube.portlets.user.td.columnwidget.client.properties.ColumnDataTypeProperties;
-import org.gcube.portlets.user.td.columnwidget.client.properties.ColumnTypeCodeProperties;
-import org.gcube.portlets.user.td.columnwidget.client.properties.LocaleTypeProperties;
 import org.gcube.portlets.user.td.columnwidget.client.properties.PeriodDataTypeProperties;
-import org.gcube.portlets.user.td.columnwidget.client.properties.TabResourceProperties;
 import org.gcube.portlets.user.td.columnwidget.client.properties.ValueDataFormatProperties;
 import org.gcube.portlets.user.td.columnwidget.client.resources.ResourceBundle;
-import org.gcube.portlets.user.td.columnwidget.client.store.ColumnDataTypeElement;
-import org.gcube.portlets.user.td.columnwidget.client.store.ColumnDataTypeStore;
-import org.gcube.portlets.user.td.columnwidget.client.store.ColumnTypeCodeElement;
-import org.gcube.portlets.user.td.columnwidget.client.store.ColumnTypeCodeStore;
-import org.gcube.portlets.user.td.columnwidget.client.store.LocaleTypeElement;
 import org.gcube.portlets.user.td.columnwidget.client.utils.UtilsGXT3;
+import org.gcube.portlets.user.td.expressionwidget.client.properties.ColumnDataPropertiesCombo;
+import org.gcube.portlets.user.td.expressionwidget.client.properties.ColumnDataTypeProperties;
+import org.gcube.portlets.user.td.expressionwidget.client.properties.ColumnTypeCodeProperties;
+import org.gcube.portlets.user.td.expressionwidget.client.properties.LocaleTypeProperties;
+import org.gcube.portlets.user.td.expressionwidget.client.properties.TabResourcePropertiesCombo;
+import org.gcube.portlets.user.td.expressionwidget.client.store.ColumnDataTypeElement;
+import org.gcube.portlets.user.td.expressionwidget.client.store.ColumnDataTypeStore;
+import org.gcube.portlets.user.td.expressionwidget.client.store.ColumnTypeCodeElement;
+import org.gcube.portlets.user.td.expressionwidget.client.store.ColumnTypeCodeStore;
+import org.gcube.portlets.user.td.expressionwidget.client.store.LocaleTypeElement;
 import org.gcube.portlets.user.td.gwtservice.client.rpc.TDGWTServiceAsync;
 import org.gcube.portlets.user.td.gwtservice.shared.exception.TDGWTIsFinalException;
 import org.gcube.portlets.user.td.gwtservice.shared.exception.TDGWTIsLockedException;
@@ -32,6 +32,7 @@ import org.gcube.portlets.user.td.gwtservice.shared.tr.column.mapping.ColumnMapp
 import org.gcube.portlets.user.td.gwtservice.shared.tr.column.type.ChangeColumnTypeSession;
 import org.gcube.portlets.user.td.monitorwidget.client.MonitorDialog;
 import org.gcube.portlets.user.td.monitorwidget.client.MonitorDialogListener;
+import org.gcube.portlets.user.td.widgetcommonevent.client.CommonMessages;
 import org.gcube.portlets.user.td.widgetcommonevent.client.event.ChangeTableRequestEvent;
 import org.gcube.portlets.user.td.widgetcommonevent.client.event.SessionExpiredEvent;
 import org.gcube.portlets.user.td.widgetcommonevent.client.type.ChangeTableRequestType;
@@ -78,7 +79,6 @@ import com.sencha.gxt.widget.core.client.event.TriggerClickEvent;
 import com.sencha.gxt.widget.core.client.event.TriggerClickEvent.TriggerClickHandler;
 import com.sencha.gxt.widget.core.client.form.ComboBox;
 import com.sencha.gxt.widget.core.client.form.FieldLabel;
-import com.sencha.gxt.widget.core.client.info.Info;
 
 /**
  * 
@@ -146,11 +146,13 @@ public class ChangeColumnTypePanel extends FramedPanel implements
 
 	private ListLoader<ListLoadConfig, ListLoadResult<ColumnData>> loader;
 
-	private TextButton change;
+	private TextButton applyBtn;
 
 	private ChangeColumnTypeSession changeColumnTypeSession;
 	private boolean panelCreated;
-
+	private ChangeColumnTypeMessages msgs;
+	private CommonMessages msgsCommon;
+	
 	public ChangeColumnTypePanel(TRId trId, String columnName, EventBus eventBus) {
 		setWidth(WIDTH);
 		setHeight(HEIGHT);
@@ -160,9 +162,15 @@ public class ChangeColumnTypePanel extends FramedPanel implements
 		this.columnName = columnName;
 		this.eventBus = eventBus;
 		panelCreated = false;
+		initMessages();
 		retrieveValueDataFormatMap();
 
 	}
+	
+	protected void initMessages(){
+		msgs = GWT.create(ChangeColumnTypeMessages.class);
+		msgsCommon = GWT.create(CommonMessages.class);
+	}
 
 	protected void retrieveValueDataFormatMap() {
 
@@ -178,8 +186,8 @@ public class ChangeColumnTypePanel extends FramedPanel implements
 
 							Log.debug("Error retrieving value data formats map: "
 									+ caught.getLocalizedMessage());
-							UtilsGXT3.alert("Error",
-									"Error retrieving value data formats map!");
+							UtilsGXT3.alert(msgsCommon.error(),
+									msgs.errorRetrievingValueDataFormatsMap());
 
 						}
 
@@ -213,19 +221,19 @@ public class ChangeColumnTypePanel extends FramedPanel implements
 						} else {
 							if (caught instanceof TDGWTIsLockedException) {
 								Log.error(caught.getLocalizedMessage());
-								UtilsGXT3.alert("Error Locked",
+								UtilsGXT3.alert(msgsCommon.errorLocked(),
 										caught.getLocalizedMessage());
 							} else {
 								if (caught instanceof TDGWTIsFinalException) {
 									Log.error(caught.getLocalizedMessage());
-									UtilsGXT3.alert("Error Final",
+									UtilsGXT3.alert(msgsCommon.errorFinal(),
 											caught.getLocalizedMessage());
 								} else {
 									Log.debug("Error retrieving column: "
 											+ caught.getLocalizedMessage());
 									UtilsGXT3
-											.alert("Error retrieving column",
-													"Error retrieving column on server!");
+											.alert(msgs.errorRetrievingColumnOnServerHead(),
+													msgs.errorRetrievingColumnOnServer());
 								}
 							}
 						}
@@ -236,8 +244,8 @@ public class ChangeColumnTypePanel extends FramedPanel implements
 					public void onSuccess(ColumnData result) {
 						Log.debug("Retrieved Column: " + result);
 						if (result == null) {
-							UtilsGXT3.alert("Error",
-									"The requested column is null");
+							UtilsGXT3.alert(msgsCommon.error(),
+									msgs.requestColumnIsNull());
 						}
 						columnRequested = result;
 						if (panelCreated) {
@@ -304,12 +312,14 @@ public class ChangeColumnTypePanel extends FramedPanel implements
 		addHandlersForComboColumn(propsColumnData.label());
 
 		comboColumn.setLoader(loader);
-		comboColumn.setEmptyText("Select a column...");
+		comboColumn.setEmptyText(msgs.comboColumnEmptyText());
 		comboColumn.setWidth(191);
 		comboColumn.setTypeAhead(false);
 		comboColumn.setEditable(false);
 		comboColumn.setTriggerAction(TriggerAction.ALL);
-
+		
+		FieldLabel comboColumnLabel=new FieldLabel(comboColumn, msgs.comboColumnLabel());
+		
 		// comboColumnTypeCode
 		ColumnTypeCodeProperties propsColumnTypeCode = GWT
 				.create(ColumnTypeCodeProperties.class);
@@ -323,13 +333,14 @@ public class ChangeColumnTypePanel extends FramedPanel implements
 
 		addHandlersForComboColumnTypeCode(propsColumnTypeCode.label());
 
-		comboColumnTypeCode.setEmptyText("Select a column type...");
+		comboColumnTypeCode.setEmptyText(msgs.comboColumnTypeCodeEmptyText());
 		comboColumnTypeCode.setWidth(191);
 		comboColumnTypeCode.setTypeAhead(true);
 		comboColumnTypeCode.setTriggerAction(TriggerAction.ALL);
 
 		comboColumnTypeCodeLabel = new FieldLabel(comboColumnTypeCode,
-				"Column Type");
+				msgs.comboColumnTypeCodeLabel());
+		
 		// comboMeasureType
 		ColumnDataTypeProperties propsMeasureType = GWT
 				.create(ColumnDataTypeProperties.class);
@@ -343,12 +354,12 @@ public class ChangeColumnTypePanel extends FramedPanel implements
 
 		addHandlersForComboMeasureType(propsMeasureType.label());
 
-		comboMeasureType.setEmptyText("Select a measure type...");
+		comboMeasureType.setEmptyText(msgs.comboMeasureTypeEmptyText());
 		comboMeasureType.setWidth(191);
 		comboMeasureType.setTypeAhead(true);
 		comboMeasureType.setTriggerAction(TriggerAction.ALL);
 
-		comboMeasureTypeLabel = new FieldLabel(comboMeasureType, "Measure Type");
+		comboMeasureTypeLabel = new FieldLabel(comboMeasureType, msgs.comboMeasureTypeLabel());
 
 		// comboAttributeType
 		ColumnDataTypeProperties propsAttributeType = GWT
@@ -363,13 +374,13 @@ public class ChangeColumnTypePanel extends FramedPanel implements
 
 		addHandlersForComboAttributeType(propsAttributeType.label());
 
-		comboAttributeType.setEmptyText("Select a column type...");
+		comboAttributeType.setEmptyText(msgs.comboAttributeTypeEmptyText());
 		comboAttributeType.setWidth(191);
 		comboAttributeType.setTypeAhead(true);
 		comboAttributeType.setTriggerAction(TriggerAction.ALL);
 
 		comboAttributeTypeLabel = new FieldLabel(comboAttributeType,
-				"Attribute Type");
+				msgs.comboAttributeTypeLabel());
 
 		// comboLocaleType
 		LocaleTypeProperties propsLocaleType = GWT
@@ -393,16 +404,16 @@ public class ChangeColumnTypePanel extends FramedPanel implements
 
 		addHandlersForComboLocaleType(propsLocaleType.label());
 
-		comboLocaleType.setEmptyText("Select a locale type...");
+		comboLocaleType.setEmptyText(msgs.comboLocaleTypeEmptyText());
 		comboLocaleType.setWidth(191);
 		comboLocaleType.setTypeAhead(true);
 		comboLocaleType.setTriggerAction(TriggerAction.ALL);
 
-		comboLocaleTypeLabel = new FieldLabel(comboLocaleType, "Locale");
+		comboLocaleTypeLabel = new FieldLabel(comboLocaleType, msgs.comboLocaleTypeLabel());
 
 		// comboDimensionType
-		TabResourceProperties propsDimensionType = GWT
-				.create(TabResourceProperties.class);
+		TabResourcePropertiesCombo propsDimensionType = GWT
+				.create(TabResourcePropertiesCombo.class);
 		storeComboDimensionType = new ListStore<TabResource>(
 				propsDimensionType.id());
 
@@ -412,12 +423,12 @@ public class ChangeColumnTypePanel extends FramedPanel implements
 
 		addHandlersForComboDimensionType(propsDimensionType.label());
 
-		comboDimensionType.setEmptyText("Select a Dimension...");
+		comboDimensionType.setEmptyText(msgs.comboDimensionTypeEmptyText());
 		comboDimensionType.setWidth(191);
 		comboDimensionType.setEditable(false);
 		comboDimensionType.setTriggerAction(TriggerAction.ALL);
 
-		comboDimensionTypeLabel = new FieldLabel(comboDimensionType, "Codelist");
+		comboDimensionTypeLabel = new FieldLabel(comboDimensionType, msgs.comboDimensionTypeLabel());
 
 		// ColumnReferenceType
 		ColumnDataPropertiesCombo propsColumnReferenceType = GWT
@@ -431,13 +442,13 @@ public class ChangeColumnTypePanel extends FramedPanel implements
 
 		addHandlersForComboColumnReferenceType(propsColumnReferenceType.label());
 
-		comboColumnReferenceType.setEmptyText("Select a Column Reference...");
+		comboColumnReferenceType.setEmptyText(msgs.comboColumnReferenceTypeEmptyText());
 		comboColumnReferenceType.setWidth(191);
 		comboColumnReferenceType.setEditable(false);
 		comboColumnReferenceType.setTriggerAction(TriggerAction.ALL);
 
 		comboColumnReferenceTypeLabel = new FieldLabel(
-				comboColumnReferenceType, "Column");
+				comboColumnReferenceType, msgs.comboColumnReferenceTypeLabel());
 
 		// ColumnMapping
 		ColumnMappingListProperties propsColumnMapping = GWT
@@ -451,12 +462,12 @@ public class ChangeColumnTypePanel extends FramedPanel implements
 
 		addHandlersForComboColumnMapping(propsColumnMapping.name());
 
-		comboColumnMapping.setEmptyText("Select optional mapping...");
+		comboColumnMapping.setEmptyText(msgs.comboColumnMappingEmptyText());
 		comboColumnMapping.setWidth(191);
 		comboColumnMapping.setEditable(false);
 		comboColumnMapping.setTriggerAction(TriggerAction.ALL);
 
-		comboColumnMappingLabel = new FieldLabel(comboColumnMapping, "Mapping");
+		comboColumnMappingLabel = new FieldLabel(comboColumnMapping, msgs.comboColumnMappingLabel());
 
 		// comboPeriodType
 		PeriodDataTypeProperties propsPeriodDataType = GWT
@@ -480,11 +491,11 @@ public class ChangeColumnTypePanel extends FramedPanel implements
 
 		addHandlersForComboPeriodType(propsPeriodDataType.label());
 
-		comboPeriodType.setEmptyText("Select a period type...");
+		comboPeriodType.setEmptyText(msgs.comboPeriodTypeEmptyText());
 		comboPeriodType.setWidth(191);
 		comboPeriodType.setTypeAhead(true);
 		comboPeriodType.setTriggerAction(TriggerAction.ALL);
-		comboPeriodTypeLabel = new FieldLabel(comboPeriodType, "Period Type");
+		comboPeriodTypeLabel = new FieldLabel(comboPeriodType, msgs.comboPeriodTypeLabel());
 
 		// comboValueDataFormat
 		ValueDataFormatProperties propsValueDataFormat = GWT
@@ -509,18 +520,18 @@ public class ChangeColumnTypePanel extends FramedPanel implements
 
 		addHandlersForComboValueDataFormat(propsValueDataFormat.label());
 
-		comboValueDataFormat.setEmptyText("Select a format...");
+		comboValueDataFormat.setEmptyText(msgs.comboValueDataFormatEmptyText());
 		comboValueDataFormat.setWidth(191);
 		comboValueDataFormat.setTypeAhead(true);
 		comboValueDataFormat.setTriggerAction(TriggerAction.ALL);
 		comboValueDataFormatLabel = new FieldLabel(comboValueDataFormat,
-				"Format");
+				msgs.comboValueDataFormatLabel());
 
-		// Change
-		change = new TextButton("Change");
-		change.setIcon(ResourceBundle.INSTANCE.columnType());
-		change.setIconAlign(IconAlign.RIGHT);
-		change.setToolTip("Change Column Type");
+		// Apply
+		applyBtn = new TextButton(msgs.applyBtnText());
+		applyBtn.setIcon(ResourceBundle.INSTANCE.columnType());
+		applyBtn.setIconAlign(IconAlign.RIGHT);
+		applyBtn.setToolTip(msgs.applyBtnToolTip());
 
 		SelectHandler changeHandler = new SelectHandler() {
 
@@ -529,10 +540,10 @@ public class ChangeColumnTypePanel extends FramedPanel implements
 
 			}
 		};
-		change.addSelectHandler(changeHandler);
+		applyBtn.addSelectHandler(changeHandler);
 
 		VerticalLayoutContainer v = new VerticalLayoutContainer();
-		v.add(new FieldLabel(comboColumn, "Column"), new VerticalLayoutData(1,
+		v.add(comboColumnLabel, new VerticalLayoutData(1,
 				-1, new Margins(1)));
 		v.add(comboColumnTypeCodeLabel, new VerticalLayoutData(1, -1,
 				new Margins(1)));
@@ -554,7 +565,7 @@ public class ChangeColumnTypePanel extends FramedPanel implements
 				new Margins(1)));
 		v.add(comboValueDataFormatLabel, new VerticalLayoutData(1, -1,
 				new Margins(1)));
-		v.add(change, new VerticalLayoutData(-1, -1, new Margins(10, 0, 10, 0)));
+		v.add(applyBtn, new VerticalLayoutData(-1, -1, new Margins(10, 0, 10, 0)));
 		add(v, new VerticalLayoutData(1, 1, new Margins(0)));
 
 		resetToInitialState();
@@ -577,12 +588,6 @@ public class ChangeColumnTypePanel extends FramedPanel implements
 			final LabelProvider<ColumnData> labelProvider) {
 		comboColumn.addSelectionHandler(new SelectionHandler<ColumnData>() {
 			public void onSelection(SelectionEvent<ColumnData> event) {
-				Info.display(
-						"Column Type Selected",
-						"You selected "
-								+ (event.getSelectedItem() == null ? "nothing"
-										: labelProvider.getLabel(event
-												.getSelectedItem()) + "!"));
 				Log.debug("ComboColumn selected: " + event.getSelectedItem());
 				ColumnData columnData = event.getSelectedItem();
 				updateComboStatus(columnData);
@@ -597,13 +602,6 @@ public class ChangeColumnTypePanel extends FramedPanel implements
 				.addSelectionHandler(new SelectionHandler<ColumnTypeCodeElement>() {
 					public void onSelection(
 							SelectionEvent<ColumnTypeCodeElement> event) {
-						Info.display(
-								"Column Type Selected",
-								"You selected "
-										+ (event.getSelectedItem() == null ? "nothing"
-												: labelProvider.getLabel(event
-														.getSelectedItem())
-														+ "!"));
 						Log.debug("ComboColumnTypeCode selected: "
 								+ event.getSelectedItem());
 						ColumnTypeCodeElement columnType = event
@@ -621,13 +619,6 @@ public class ChangeColumnTypePanel extends FramedPanel implements
 				.addSelectionHandler(new SelectionHandler<ColumnDataTypeElement>() {
 					public void onSelection(
 							SelectionEvent<ColumnDataTypeElement> event) {
-						Info.display(
-								"Measure Type Selected",
-								"You selected "
-										+ (event.getSelectedItem() == null ? "nothing"
-												: labelProvider.getLabel(event
-														.getSelectedItem())
-														+ "!"));
 						Log.debug("ComboMeasureType selected: "
 								+ event.getSelectedItem());
 						ColumnDataTypeElement measureType = event
@@ -644,13 +635,6 @@ public class ChangeColumnTypePanel extends FramedPanel implements
 				.addSelectionHandler(new SelectionHandler<ColumnDataTypeElement>() {
 					public void onSelection(
 							SelectionEvent<ColumnDataTypeElement> event) {
-						Info.display(
-								"Attribute Type Selected",
-								"You selected "
-										+ (event.getSelectedItem() == null ? "nothing"
-												: labelProvider.getLabel(event
-														.getSelectedItem())
-														+ "!"));
 						Log.debug("ComboAttributeType selected: "
 								+ event.getSelectedItem());
 						ColumnDataTypeElement attributeType = event
@@ -667,13 +651,6 @@ public class ChangeColumnTypePanel extends FramedPanel implements
 				.addSelectionHandler(new SelectionHandler<LocaleTypeElement>() {
 					public void onSelection(
 							SelectionEvent<LocaleTypeElement> event) {
-						Info.display(
-								"Locale Type Selected",
-								"You selected "
-										+ (event.getSelectedItem() == null ? "nothing"
-												: labelProvider.getLabel(event
-														.getSelectedItem())
-														+ "!"));
 						Log.debug("ComboLocaleType selected: "
 								+ event.getSelectedItem());
 						LocaleTypeElement localeType = event.getSelectedItem();
@@ -706,13 +683,6 @@ public class ChangeColumnTypePanel extends FramedPanel implements
 		comboColumnReferenceType
 				.addSelectionHandler(new SelectionHandler<ColumnData>() {
 					public void onSelection(SelectionEvent<ColumnData> event) {
-						Info.display(
-								"Column Reference Selected",
-								"You selected "
-										+ (event.getSelectedItem() == null ? "nothing"
-												: labelProvider.getLabel(event
-														.getSelectedItem())
-														+ "!"));
 						Log.debug("ComboColumnReferenceType selected: "
 								+ event.getSelectedItem());
 
@@ -744,13 +714,6 @@ public class ChangeColumnTypePanel extends FramedPanel implements
 		comboPeriodType
 				.addSelectionHandler(new SelectionHandler<PeriodDataType>() {
 					public void onSelection(SelectionEvent<PeriodDataType> event) {
-						Info.display(
-								"Period Type Selected",
-								"You selected "
-										+ (event.getSelectedItem() == null ? "nothing"
-												: labelProvider.getLabel(event
-														.getSelectedItem())
-														+ "!"));
 						Log.debug("ComboPeriodType selected: "
 								+ event.getSelectedItem());
 						PeriodDataType periodDataType = event.getSelectedItem();
@@ -766,13 +729,6 @@ public class ChangeColumnTypePanel extends FramedPanel implements
 				.addSelectionHandler(new SelectionHandler<ValueDataFormat>() {
 					public void onSelection(
 							SelectionEvent<ValueDataFormat> event) {
-						Info.display(
-								"Time Format Selected",
-								"You selected "
-										+ (event.getSelectedItem() == null ? "nothing"
-												: labelProvider.getLabel(event
-														.getSelectedItem())
-														+ "!"));
 						Log.debug("ComboTimeDataFormat selected: "
 								+ event.getSelectedItem());
 						ValueDataFormat timeDataFormat = event
@@ -915,18 +871,18 @@ public class ChangeColumnTypePanel extends FramedPanel implements
 						} else {
 							if (caught instanceof TDGWTIsLockedException) {
 								Log.error(caught.getLocalizedMessage());
-								UtilsGXT3.alert("Error Locked",
+								UtilsGXT3.alert(msgsCommon.errorLocked(),
 										caught.getLocalizedMessage());
 							} else {
 								if (caught instanceof TDGWTIsFinalException) {
 									Log.error(caught.getLocalizedMessage());
-									UtilsGXT3.alert("Error Final",
+									UtilsGXT3.alert(msgsCommon.errorFinal(),
 											caught.getLocalizedMessage());
 								} else {
 									Log.error("load combo failure:"
 											+ caught.getLocalizedMessage());
-									UtilsGXT3.alert("Error",
-											"Error retrieving columns of tabular resource:"
+									UtilsGXT3.alert(msgsCommon.error(),
+											msgs.errorRetrievingColumnsOfTabularResource()
 													+ trId.getId());
 								}
 							}
@@ -965,7 +921,7 @@ public class ChangeColumnTypePanel extends FramedPanel implements
 				}
 			}
 		} else {
-			change.disable();
+			applyBtn.disable();
 			comboColumnTypeCode.reset();
 			comboColumnTypeCodeLabel.setVisible(false);
 		}
@@ -1093,19 +1049,19 @@ public class ChangeColumnTypePanel extends FramedPanel implements
 						} else {
 							if (caught instanceof TDGWTIsLockedException) {
 								Log.error(caught.getLocalizedMessage());
-								UtilsGXT3.alert("Error Locked",
+								UtilsGXT3.alert(msgsCommon.errorLocked(),
 										caught.getLocalizedMessage());
 							} else {
 								if (caught instanceof TDGWTIsFinalException) {
 									Log.error(caught.getLocalizedMessage());
-									UtilsGXT3.alert("Error Final",
+									UtilsGXT3.alert(msgsCommon.errorFinal(),
 											caught.getLocalizedMessage());
 								} else {
 									Log.error("load column failure:"
 											+ caught.getLocalizedMessage());
 									UtilsGXT3
-											.alert("Error retrieving connection",
-													"Error retrieving connection column");
+											.alert(msgs.errorRetrievingConnectionHead(),
+													msgs.errorRetrievingConnection());
 								}
 							}
 						}
@@ -1124,19 +1080,19 @@ public class ChangeColumnTypePanel extends FramedPanel implements
 	protected void updateConfBtnChange(ColumnData columnReference) {
 		if (connectionColumn == null) {
 			if (columnReference != null) {
-				change.enable();
+				applyBtn.enable();
 			} else {
-				change.disable();
+				applyBtn.disable();
 			}
 		} else {
 			if (columnReference == null) {
-				change.disable();
+				applyBtn.disable();
 			} else {
 				if (columnReference.getColumnId().compareTo(
 						connectionColumn.getColumnId()) == 0) {
-					change.disable();
+					applyBtn.disable();
 				} else {
-					change.enable();
+					applyBtn.enable();
 				}
 			}
 
@@ -1147,7 +1103,7 @@ public class ChangeColumnTypePanel extends FramedPanel implements
 		if (columnTypeCode == null) {
 			ColumnTypeCodeElement codeElement = comboColumnTypeCode.getValue();
 			if (codeElement == null) {
-				change.disable();
+				applyBtn.disable();
 			} else {
 				configureBtnChange(codeElement.getCode());
 			}
@@ -1156,48 +1112,48 @@ public class ChangeColumnTypePanel extends FramedPanel implements
 		}
 	}
 
-	// TODO
+	//
 	protected void configureBtnChange(ColumnTypeCode columnTypeCode) {
 		ColumnTypeCode sourceTypeCode = ColumnTypeCode
 				.getColumnTypeCodeFromId(sourceColumnChangeType.getTypeCode());
 
 		switch (sourceTypeCode) {
 		case ANNOTATION:
-			change.enable();
+			applyBtn.enable();
 			break;
 		case ATTRIBUTE:
-			change.enable();
+			applyBtn.enable();
 			break;
 		case CODE:
-			change.enable();
+			applyBtn.enable();
 			break;
 		case CODEDESCRIPTION:
-			change.enable();
+			applyBtn.enable();
 			break;
 		case CODENAME:
-			change.enable();
+			applyBtn.enable();
 			break;
 		case DIMENSION:
 			if (columnTypeCode.compareTo(ColumnTypeCode.DIMENSION) == 0
 					|| columnTypeCode.compareTo(ColumnTypeCode.TIMEDIMENSION) == 0) {
-				change.disable();
+				applyBtn.disable();
 			} else {
-				change.enable();
+				applyBtn.enable();
 			}
 			break;
 		case MEASURE:
-			change.enable();
+			applyBtn.enable();
 			break;
 		case TIMEDIMENSION:
 			if (columnTypeCode.compareTo(ColumnTypeCode.DIMENSION) == 0
 					|| columnTypeCode.compareTo(ColumnTypeCode.TIMEDIMENSION) == 0) {
-				change.disable();
+				applyBtn.disable();
 			} else {
-				change.enable();
+				applyBtn.enable();
 			}
 			break;
 		default:
-			change.enable();
+			applyBtn.enable();
 			break;
 		}
 
@@ -1229,18 +1185,18 @@ public class ChangeColumnTypePanel extends FramedPanel implements
 										.setValueDataFormat(valueDataFormat);
 								callChangeColumnType();
 							} else {
-								UtilsGXT3.alert("Attention",
-										"Type format not selected!");
+								UtilsGXT3.alert(msgsCommon.attention(),
+										msgs.typeFormatNotSelected());
 							}
 
 						} else {
-							UtilsGXT3.alert("Attention",
-									"Column data type not selected!");
+							UtilsGXT3.alert(msgsCommon.attention(),
+									msgs.columnDataTypeNotSelected());
 						}
 
 					} else {
-						UtilsGXT3.alert("Attention",
-								"Column data type not selected!");
+						UtilsGXT3.alert(msgsCommon.attention(),
+								msgs.columnDataTypeNotSelected());
 					}
 					break;
 				case ATTRIBUTE:
@@ -1262,16 +1218,16 @@ public class ChangeColumnTypePanel extends FramedPanel implements
 										.setValueDataFormat(valueDataFormat);
 								callChangeColumnType();
 							} else {
-								UtilsGXT3.alert("Attention",
-										"Type format not selected!");
+								UtilsGXT3.alert(msgsCommon.attention(),
+										msgs.typeFormatNotSelected());
 							}
 						} else {
-							UtilsGXT3.alert("Attention",
-									"Column data type not selected!");
+							UtilsGXT3.alert(msgsCommon.attention(),
+									msgs.columnDataTypeNotSelected());
 						}
 					} else {
-						UtilsGXT3.alert("Attention",
-								"Column data type not selected!");
+						UtilsGXT3.alert(msgsCommon.attention(),
+								msgs.columnDataTypeNotSelected());
 					}
 					break;
 				case CODE:
@@ -1287,7 +1243,7 @@ public class ChangeColumnTypePanel extends FramedPanel implements
 								.getLocaleName());
 						callChangeColumnType();
 					} else {
-						UtilsGXT3.alert("Attention", "No locale selected!");
+						UtilsGXT3.alert(msgsCommon.attention(), msgs.noLocaleSelected());
 					}
 					break;
 				case CODEDESCRIPTION:
@@ -1313,8 +1269,8 @@ public class ChangeColumnTypePanel extends FramedPanel implements
 								.setCodelistColumnReference(columnReference);
 						callChangeColumnType();
 					} else {
-						UtilsGXT3.alert("Attention",
-								"No column reference selected!");
+						UtilsGXT3.alert(msgsCommon.attention(),
+								msgs.referenceColumnNotSelected());
 					}
 					break;
 				case TIMEDIMENSION:
@@ -1331,25 +1287,25 @@ public class ChangeColumnTypePanel extends FramedPanel implements
 									.setValueDataFormat(timeDataFormat);
 							callChangeColumnType();
 						} else {
-							UtilsGXT3.alert("Attention",
-									"Time Format not selected!");
+							UtilsGXT3.alert(msgsCommon.attention(),
+									msgs.timeFormatNotSelected());
 						}
 
 					} else {
-						UtilsGXT3.alert("Attention",
-								"Period Type not selected!");
+						UtilsGXT3.alert(msgsCommon.attention(),
+								msgs.periodTypeNotSelected());
 					}
 					break;
 				default:
-					UtilsGXT3.alert("Attention",
-							"This column type is not supported now!");
+					UtilsGXT3.alert(msgsCommon.attention(),
+							msgs.thisColumnTypeIsNotSupportedForNow());
 					break;
 				}
 			} else {
-				UtilsGXT3.alert("Attention", "Select a column type!");
+				UtilsGXT3.alert(msgsCommon.attention(), msgs.selectAColumnType());
 			}
 		} else {
-			UtilsGXT3.alert("Attention", "Select a column!");
+			UtilsGXT3.alert(msgsCommon.attention(), msgs.selectAColumn());
 		}
 	}
 
@@ -1363,19 +1319,19 @@ public class ChangeColumnTypePanel extends FramedPanel implements
 						} else {
 							if (caught instanceof TDGWTIsLockedException) {
 								Log.error(caught.getLocalizedMessage());
-								UtilsGXT3.alert("Error Locked",
+								UtilsGXT3.alert(msgsCommon.errorLocked(),
 										caught.getLocalizedMessage());
 							} else {
 								if (caught instanceof TDGWTIsFinalException) {
 									Log.error(caught.getLocalizedMessage());
-									UtilsGXT3.alert("Error Final",
+									UtilsGXT3.alert(msgsCommon.errorFinal(),
 											caught.getLocalizedMessage());
 								} else {
 									Log.debug("Change Column Type Error: "
 											+ caught.getLocalizedMessage());
 									UtilsGXT3
-											.alert("Change Column Type Error ",
-													"Error in invocation of  change column type operation!");
+											.alert(msgs.changeColumnTypeErrorHead(),
+													msgs.changeColumnTypeError());
 								}
 							}
 						}
@@ -1430,19 +1386,19 @@ public class ChangeColumnTypePanel extends FramedPanel implements
 						} else {
 							if (caught instanceof TDGWTIsLockedException) {
 								Log.error(caught.getLocalizedMessage());
-								UtilsGXT3.alert("Error Locked",
+								UtilsGXT3.alert(msgsCommon.errorLocked(),
 										caught.getLocalizedMessage());
 							} else {
 								if (caught instanceof TDGWTIsFinalException) {
 									Log.error(caught.getLocalizedMessage());
-									UtilsGXT3.alert("Error Final",
+									UtilsGXT3.alert(msgsCommon.errorFinal(),
 											caught.getLocalizedMessage());
 								} else {
 									Log.debug("Error retrieving columns: "
 											+ caught.getLocalizedMessage());
 									UtilsGXT3
-											.alert("Error retrieving columns",
-													"Error retrieving columns on server!");
+											.alert(msgs.errorRetrievingColumnOnServerHead(),
+													msgs.errorRetrievingColumnOnServer());
 								}
 							}
 						}
@@ -1473,19 +1429,19 @@ public class ChangeColumnTypePanel extends FramedPanel implements
 						} else {
 							if (caught instanceof TDGWTIsLockedException) {
 								Log.error(caught.getLocalizedMessage());
-								UtilsGXT3.alert("Error Locked",
+								UtilsGXT3.alert(msgsCommon.errorLocked(),
 										caught.getLocalizedMessage());
 							} else {
 								if (caught instanceof TDGWTIsFinalException) {
 									Log.error(caught.getLocalizedMessage());
-									UtilsGXT3.alert("Error Final",
+									UtilsGXT3.alert(msgsCommon.errorFinal(),
 											caught.getLocalizedMessage());
 								} else {
 									Log.debug("Error retrieving columns: "
 											+ caught.getLocalizedMessage());
 									UtilsGXT3
-											.alert("Error retrieving columns",
-													"Error retrieving columns on server!");
+											.alert(msgs.errorRetrievingColumnOnServerHead(),
+													msgs.errorRetrievingColumnOnServer());
 								}
 							}
 						}
@@ -1518,18 +1474,18 @@ public class ChangeColumnTypePanel extends FramedPanel implements
 						} else {
 							if (caught instanceof TDGWTIsLockedException) {
 								Log.error(caught.getLocalizedMessage());
-								UtilsGXT3.alert("Error Locked",
+								UtilsGXT3.alert(msgsCommon.errorLocked(),
 										caught.getLocalizedMessage());
 							} else {
 								if (caught instanceof TDGWTIsFinalException) {
 									Log.error(caught.getLocalizedMessage());
-									UtilsGXT3.alert("Error Final",
+									UtilsGXT3.alert(msgsCommon.errorFinal(),
 											caught.getLocalizedMessage());
 								} else {
 									Log.debug("Error retrieving tabular resource: "
 											+ caught.getLocalizedMessage());
 									UtilsGXT3
-											.alert("Error retrieving tabular resource",
+											.alert(msgs.errorRetrievingTabularResource(),
 													caught.getLocalizedMessage());
 								}
 							}
@@ -1560,16 +1516,16 @@ public class ChangeColumnTypePanel extends FramedPanel implements
 						} else {
 							if (caught instanceof TDGWTIsLockedException) {
 								Log.error(caught.getLocalizedMessage());
-								UtilsGXT3.alert("Error Locked",
+								UtilsGXT3.alert(msgsCommon.errorLocked(),
 										caught.getLocalizedMessage());
 							} else {
 								if (caught instanceof TDGWTIsFinalException) {
 									Log.error(caught.getLocalizedMessage());
-									UtilsGXT3.alert("Error Final",
+									UtilsGXT3.alert(msgsCommon.errorFinal(),
 											caught.getLocalizedMessage());
 								} else {
 									Log.debug(caught.getLocalizedMessage());
-									UtilsGXT3.alert("Error retrieving locales",
+									UtilsGXT3.alert(msgs.errorRetrievingLocales(),
 											caught.getLocalizedMessage());
 								}
 							}
@@ -1606,17 +1562,17 @@ public class ChangeColumnTypePanel extends FramedPanel implements
 						} else {
 							if (caught instanceof TDGWTIsLockedException) {
 								Log.error(caught.getLocalizedMessage());
-								UtilsGXT3.alert("Error Locked",
+								UtilsGXT3.alert(msgsCommon.errorLocked(),
 										caught.getLocalizedMessage());
 							} else {
 								if (caught instanceof TDGWTIsFinalException) {
 									Log.error(caught.getLocalizedMessage());
-									UtilsGXT3.alert("Error Final",
+									UtilsGXT3.alert(msgsCommon.errorFinal(),
 											caught.getLocalizedMessage());
 								} else {
 									Log.debug(caught.getLocalizedMessage());
 									UtilsGXT3.alert(
-											"Error retrieving period type",
+											msgs.errorRetrievingPeriodType(),
 											caught.getLocalizedMessage());
 								}
 							}
@@ -1648,19 +1604,19 @@ public class ChangeColumnTypePanel extends FramedPanel implements
 	protected void callColumnMappingDialog() {
 		ColumnData selectedColumn = comboColumn.getCurrentValue();
 		if (selectedColumn == null) {
-			UtilsGXT3.alert("Attention", "Column not selected!");
+			UtilsGXT3.alert(msgsCommon.attention(), msgs.columnNotSelected());
 			return;
 		}
 
 		TabResource dimensionTR = comboDimensionType.getValue();
 		if (dimensionTR == null) {
-			UtilsGXT3.alert("Attention", "Codelist not selected!");
+			UtilsGXT3.alert(msgsCommon.attention(), msgs.codelistNotSelected());
 			return;
 		}
 
 		ColumnData referenceColumn = comboColumnReferenceType.getValue();
 		if (referenceColumn == null) {
-			UtilsGXT3.alert("Attention", "Reference column not selected!");
+			UtilsGXT3.alert(msgsCommon.attention(), msgs.referenceColumnNotSelected());
 			return;
 		}
 
